Method: Vips.block

Defined in:
lib/vips.rb

.block(operation_name, state) ⇒ Object

Block/unblock all operations in the libvips class hierarchy at specified operation_name and below.

For example this will block all loaders except JPEG

Vips.block("VipsForeignLoad", true); Vips.block("VipsForeignLoadJpeg", false)

Use vips -l at the command-line to see the class hierarchy. This call does nothing if the named operation is not found.



847
848
849
# File 'lib/vips.rb', line 847

def self.block(operation_name, state)
  vips_operation_block_set(operation_name, state ? 1 : 0)
end