Method: Vips::Image#new_from_image
- Defined in:
- lib/vips/image.rb
#new_from_image(value) ⇒ Image
A new image is created with the same width, height, format, interpretation, resolution and offset as self, but with every pixel set to the specified value.
You can pass an array to make a many-band image, or a single value to make a one-band image.
559 560 561 562 563 564 |
# File 'lib/vips/image.rb', line 559 def new_from_image value pixel = (Vips::Image.black(1, 1) + value).cast(format) image = pixel. 0, 0, width, height, extend: :copy image.copy interpretation: interpretation, xres: xres, yres: yres, xoffset: xoffset, yoffset: yoffset end |